@@ -1,4 +1,4 @@
-# $Id: MachTen.pm,v 1.3 2008/10/27 20:31:21 drhyde Exp $
+# $Id: MachTen.pm,v 1.4 2008/11/05 22:52:34 drhyde Exp $
 
 package Devel::AssertOS::MachTen;
 
@@ -8,6 +8,13 @@ $VERSION = '1.1';
 
 sub os_is { $^O eq 'machten' ? 1 : 0; }
 
+sub expn {
+join("\n",
+"You're using the Mach Ten BSD-compatible environment on top of",
+"Mac OS 'Classic' - ie, a pre-OS-X version of Mac OS.",
+)
+}
+
 Devel::CheckOS::die_unsupported() unless(os_is());
 
 =head1 COPYRIGHT and LICENCE
